# Security Policy

## Supported Versions

Which versions of your project are
currently being supported with security updates.

| Version | Supported          | ``semantic-release`` Version |
| ------- | ------------------ | -----------------------------|
| <1.28.x  | ❌                 | 9.15                         |
| 1.29.x  | ☑️                 | 9.15                         |
| 1.30.x  | ☑️                 | 9.15                         |
| 1.31.x  | ☑️                 | 9.15                         |
| 1.32.x  | ☑️                 | 9.15                         |
| 1.33.x  | ☑️                 | 9.16                         |
| 1.34.x  | ☑️                 | 9.17                         |
| 1.35.x  | ☑️                 | 9.19                         |
| 1.36.x  | ☑️                 | 9.20                         |
| 1.37.x  | ☑️                 | 9.21                         |
| 1.38.x  | ☑️                 | 9.21                         |

## Disclosure

All known security vulnerabilities must be disclosed publically within 30 days of a detection during regular monitoring.

## Reporting a Vulnerability

A security vulnerability must never be posted in Issues.
This must be done directly through GitHub or via help@oziproject.dev

